@@ -12,7 +12,8 @@ output$ui_repo_directory <- renderUI({
     init <- shinyFiles::parseDirPath(gg_volumes, input$repo_directory_find)
   }
   textInput(
-    "repo_directory", NULL, value = init,
+    "repo_directory", NULL,
+    value = init,
     placeholder = "Repo directory"
   )
 })
@@ -21,15 +22,15 @@ outputOptions(output, "ui_repo_directory", suspendWhenHidden = FALSE)
 
 is_repo <- reactive({
   input$repo_refresh
-  suppressWarnings(system(paste("git -C", input$repo_directory, "rev-parse --is-inside-work-tree 2>/dev/null"), intern = TRUE))
+  is_repo_fun(input$repo_directory)
 })
 
 output$repo_output <- renderPrint({
   req(input$repo_directory)
   input$repo_refresh
-  if (is_empty(is_repo())) {
-    cat(paste(input$repo_directory, "is not a git repo"))
-  } else {
+  if (is_repo()) {
     cat(paste(input$repo_directory, "is a git repo"))
+  } else {
+    cat(paste(input$repo_directory, "is not a git repo"))
   }
 })
